@@ -57,7 +57,7 @@ char* errmsg(int errnum, char* buf, size_t buflen) {
 #elif defined(__APPLE__)
   strerror_r(errnum, buf, buflen);
   return buf;
-#elif (_POSIX_C_SOURCE >= 200112L || _XOPEN_SOURCE >= 600) && !_GNU_SOURCE
+#elif ((_POSIX_C_SOURCE >= 200112L || _XOPEN_SOURCE >= 600) && !_GNU_SOURCE) || __MUSL__
   strerror_r(errnum, buf, buflen);
   return buf;
 #else
